@@ -10,12 +10,11 @@ use base 'Exporter';
 our @EXPORT = ();
 our @EXPORT_OK = qw/
   jq_getsome
-  jq_getsomep
   jq_locked
   jq_queued
-  jq_prime_skiplist
   jq_log
   jq_userlog
+  jq_take
   jq_lock
   jq_defer
   jq_complete
@@ -43,10 +42,6 @@ Returns a list of randomly selected queued jobs. Default is to return one job,
 unless C<$num> is provided. Jobs are returned as objects which implement the
 Netdisco job instance interface (see below).
 
-=head2 jq_getsomep( $num? )
-
-Same as C<jq_getsome> but for high priority jobs.
-
 =head2 jq_locked()
 
 Returns the list of jobs currently booked out to this processing node (denoted
@@ -58,12 +53,6 @@ Netdisco job instance interface (see below).
 Returns a list of IP addresses of devices which currently have a job of the
 given C<$job_type> queued (e.g. C<discover>, C<arpnip>, etc).
 
-=head2 jq_prime_skiplist()
-
-Sets up a table of hints for the backend daemon manager to help avoid picking
-jobs from the queue that it cannot process due to C<*_no> configuration
-settings.
-
 =head2 jq_log()
 
 Returns a list of the most recent 50 jobs in the queue. Jobs are returned as
@@ -75,6 +64,12 @@ Returns a list of jobs which have been entered into the queue by the passed
 C<$user>. Jobs are returned as objects which implement the Netdisco job
 instance interface (see below).
 
+=head2 jq_take( $wid, $type, $max? )
+
+Searches in the queue for jobs of type C<$type> and if up to C<$max> are
+available, will book them out to the worker with ID C<$wid>. The default
+number of booked jobs is 1.
+
 =head2 jq_lock( $job )
 
 Marks a job in the queue as booked out to this processing node (denoted by the
@@ -113,6 +108,10 @@ jobs from the queue.
 
 =head2 id (auto)
 
+=head2 type (required)
+
+=head2 wid (required, default 0)
+
 =head2 entered
 
 =head2 started
