@@ -21,7 +21,7 @@ set(
 );
 
 # this is what Dancer::Template::TemplateToolkit does by default
-config->{engines}->{template_toolkit}->{INCLUDE_PATH} ||= [ setting('views') ];
+config->{engines}->{netdisco_template_toolkit}->{INCLUDE_PATH} ||= [ setting('views') ];
 
 register 'register_template_path' => sub {
   my ($self, $path) = plugin_args(@_);
@@ -30,9 +30,8 @@ register 'register_template_path' => sub {
       return error "bad template path to register_template_paths";
   }
 
-  unshift
-    @{ config->{engines}->{template_toolkit}->{INCLUDE_PATH} },
-    $path, dir($path, 'views')->stringify;
+  push @{ config->{engines}->{netdisco_template_toolkit}->{INCLUDE_PATH} },
+       dir($path, 'views')->stringify;
 };
 
 sub _register_include {
